--- asterisk-1.0.cvs/asterisk/channels/chan_zap.c	2004-10-19 18:14:08.000000000 -0700
+++ asterisk-1.0.scrd/asterisk/channels/chan_zap.c	2004-10-19 18:13:25.000000000 -0700
@@ -8696,6 +8696,96 @@
 	handle_zap_set_gain, "Override gain settings",
 	zap_set_gain_usage, NULL };
 
+static char zap_set_echo_taps_usage[] =
+	"Usage: zap set echo taps <chan num> <0/32/68/128/256>\n"
+	"	Immediatly override the number of taps that were loaded from zapata.conf\n";
+
+static int handle_zap_set_echo_taps(int fd, int argc, char **argv)
+{
+	int channel = 0;
+        int numtaps = 0;
+        int old_numtaps = 0;
+
+        struct zt_pvt *tmp = NULL;
+
+	if (argc != 6) 
+		return RESULT_SHOWUSAGE;
+
+	if ((sscanf(argv[4], "%d", &channel) != 1) ||
+		(sscanf(argv[5], "%d", &numtaps) != 1) ||
+		!((numtaps ==0) ||
+		  (numtaps == 32) ||
+		  (numtaps == 64) ||
+		  (numtaps == 128) ||
+		  (numtaps == 256)
+		))
+		return RESULT_SHOWUSAGE;
+
+	tmp = iflist;
+	while (tmp) {
+		if (tmp->channel == channel) {
+			/* change the in memory configuration of the channel */
+			old_numtaps = tmp->echocancel;
+			tmp->echocancel = numtaps;
+
+			ast_cli(fd, "Changed number of taps from %d to %d on channel %d\n", old_numtaps, numtaps, channel);
+			return RESULT_SUCCESS;
+		}
+		tmp = tmp->next;
+	}
+
+	ast_cli(fd, "Unable to find channel %d\n", channel);
+	return RESULT_FAILURE;
+}
+
+static struct ast_cli_entry zap_set_echo_taps_cli =
+	{ { "zap", "set", "echo", "taps", NULL },
+	handle_zap_set_echo_taps, "Override echo tap settings",
+	zap_set_echo_taps_usage, NULL };
+
+static char zap_set_echo_training_usage[] =
+	"Usage: zap set echo training <chan num> <offset ms>\n"
+	"	Immediatly override the number of training that were loaded from zapata.conf\n";
+
+static int handle_zap_set_echo_training(int fd, int argc, char **argv)
+{
+	int channel = 0;
+        int training = 0;
+        int old_training = 0;
+
+        struct zt_pvt *tmp = NULL;
+
+	if (argc != 6) 
+		return RESULT_SHOWUSAGE;
+
+	if (sscanf(argv[4], "%d", &channel) != 1) 
+		return RESULT_SHOWUSAGE;
+	
+	if (sscanf(argv[5], "%d", &training) != 1) 
+		return RESULT_SHOWUSAGE;
+
+	tmp = iflist;
+	while (tmp) {
+		if (tmp->channel == channel) {
+			/* change the in memory configuration of the channel */
+			old_training = tmp->echotraining;
+			tmp->echotraining = training;
+
+			ast_cli(fd, "Changed echo training from %d to %d on channel %d\n", old_training, training, channel);
+			return RESULT_SUCCESS;
+		}
+		tmp = tmp->next;
+	}
+
+	ast_cli(fd, "Unable to find channel %d\n", channel);
+	return RESULT_FAILURE;
+}
+
+static struct ast_cli_entry zap_set_echo_training_cli =
+	{ { "zap", "set", "echo", "training", NULL },
+	handle_zap_set_echo_training, "Override echo tap settings",
+	zap_set_echo_training_usage, NULL };
+
 static char show_channels_usage[] =
 	"Usage: zap show channels\n"
 	"	Shows a list of available channels\n";
@@ -8933,6 +9022,8 @@
 	ast_cli_unregister(&cli_destroy_channel);
 	ast_cli_unregister(&zap_show_cadences_cli);
 	ast_cli_unregister(&zap_set_gain_cli);
+	ast_cli_unregister(&zap_set_echo_taps_cli);
+	ast_cli_unregister(&zap_set_echo_training_cli);
 	ast_manager_unregister( "ZapDialOffhook" );
 	ast_manager_unregister( "ZapHangup" );
 	ast_manager_unregister( "ZapTransfer" );
@@ -9736,6 +9827,8 @@
 	ast_cli_register(&cli_destroy_channel);
 	ast_cli_register(&zap_show_cadences_cli);
 	ast_cli_register(&zap_set_gain_cli);
+	ast_cli_register(&zap_set_echo_taps_cli);
+	ast_cli_register(&zap_set_echo_training_cli);
 
 	ast_register_application(app_callingpres, change_callingpres, synopsis_callingpres, descrip_callingpres);
 	memset(round_robin, 0, sizeof(round_robin));
